import sinon from 'sinon';
import { service as creditLockContracts } from './creditLockContracts.js';

const urlParams = {
  document: '321321321',
  financialInstitutionIspb: 'fi',
  validFrom: '2018-06-02',
  validTo: '2019-06-02',
  page: 0,
  pageSize: 10,
};

describe('Partial Lock Credit Lock Contracts Module', () => {
  it('Should have methods after initialization.', () => {
    const service = creditLockContracts();
    expect(service.get).to.be.a('function');
  });

  it('Should call get request.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = creditLockContracts(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledOnce;
  });

  it('Should call get request and return a valid URL.', () => {
    const spy = sinon.spy();

    const getRequest = (makeUrl) => {
      spy(makeUrl(urlParams));
      return () => {};
    };

    const service = creditLockContracts(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been
      .calledWith('v0/merchants/321321321/credit-lock-contracts?' +
        'financialInstitutionIspb=fi&validFrom=2018-06-02&validTo=2019-06-02' +
        '&page=0&pageSize=10');
  });

  it('Should call get request with valid params.', () => {
    const spy = sinon.spy();

    const getRequest = () => spy;

    const service = creditLockContracts(getRequest);

    service.get(urlParams);

    expect(spy).to.have.been.calledWith(urlParams);
  });
});
